@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Pandas Dataframe accessor for PRQL.
 
 Examples
@@ -6,7 +5,7 @@ Examples
 import  pandas as pd
 import pyprql.pandas
 df = pd.DataFrame({})
-results_df = df.prql.query('from df | select [age,name,occupation] | filter age > 21')
+results_df = df.prql.query('select [age,name,occupation] | filter age > 21')
 
 """
 
@@ -21,4 +20,10 @@ class PrqlAccessor:
         self._obj = pandas_obj
 
     def query(self, prql_query: str) -> pd.DataFrame:
-        return duckdb.query(prql.to_sql(prql_query)).to_df()
+        prepended_query = f"from df \n {prql_query}"
+        sql_query = prql.to_sql(prepended_query)
+        return duckdb.query_df(
+            self._obj,
+            virtual_table_name="df",
+            sql_query=sql_query,
+        ).fetch_df()
